package com.ruoyi.ems.record.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.ems.record.domain.EmsRecordWaterInstant;
import com.ruoyi.ems.record.service.IEmsRecordWaterInstantService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 水实时数据Controller
 * 
 * @author Yinq
 * @date 2024-05-14
 */
@RestController
@RequestMapping("/ems/record/recordWaterInstant")
public class EmsRecordWaterInstantController extends BaseController
{
    @Autowired
    private IEmsRecordWaterInstantService emsRecordWaterInstantService;

    /**
     * 查询水实时数据列表
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordWaterInstant:list')")
    @GetMapping("/list")
    public TableDataInfo list(EmsRecordWaterInstant emsRecordWaterInstant)
    {
        startPage();
        List<EmsRecordWaterInstant> list = emsRecordWaterInstantService.selectEmsRecordWaterInstantList(emsRecordWaterInstant);
        return getDataTable(list);
    }

    /**
     * 导出水实时数据列表
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordWaterInstant:export')")
    @Log(title = "水实时数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EmsRecordWaterInstant emsRecordWaterInstant)
    {
        List<EmsRecordWaterInstant> list = emsRecordWaterInstantService.selectEmsRecordWaterInstantList(emsRecordWaterInstant);
        ExcelUtil<EmsRecordWaterInstant> util = new ExcelUtil<EmsRecordWaterInstant>(EmsRecordWaterInstant.class);
        util.exportExcel(response, list, "水实时数据数据");
    }

    /**
     * 获取水实时数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordWaterInstant:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId)
    {
        return success(emsRecordWaterInstantService.selectEmsRecordWaterInstantByObjId(objId));
    }

    /**
     * 新增水实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordWaterInstant:add')")
    @Log(title = "水实时数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EmsRecordWaterInstant emsRecordWaterInstant)
    {
        emsRecordWaterInstant.setCreateBy(getUsername());
        return toAjax(emsRecordWaterInstantService.insertEmsRecordWaterInstant(emsRecordWaterInstant));
    }

    /**
     * 修改水实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordWaterInstant:edit')")
    @Log(title = "水实时数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EmsRecordWaterInstant emsRecordWaterInstant)
    {
        emsRecordWaterInstant.setUpdateBy(getUsername());
        return toAjax(emsRecordWaterInstantService.updateEmsRecordWaterInstant(emsRecordWaterInstant));
    }

    /**
     * 删除水实时数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordWaterInstant:remove')")
    @Log(title = "水实时数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds)
    {
        return toAjax(emsRecordWaterInstantService.deleteEmsRecordWaterInstantByObjIds(objIds));
    }
}
